@@ -224,6 +224,7 @@ d_inetaton='undef'
 d_inetntop='undef'
 d_inetpton='undef'
 d_int64_t='undef'
+d_ip_mreq='undef'
 d_ipv6_mreq='undef'
 d_isascii='undef'
 d_isblank='undef'
@@ -425,7 +426,7 @@ d_strftime='undef'
 d_strlcat='undef'
 d_strlcpy='undef'
 d_strtod='undef'
-d_strtol='undef'
+d_strtol='define'
 d_strtold='undef'
 d_strtoll='undef'
 d_strtoq='undef'
